wurm

package
v0.0.0-...-3b1d4bc Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 16, 2025 License: MIT Imports: 12 Imported by: 0

Documentation

Overview

Package wurm implements the required functions to use Wurm as a library.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New() *application

New creates and returns a new application instance. It uses the global configuration if a configuration file is'nt present.

func Run

func Run(table string)

Run creates a new application instance. It uses the table argument to read the associated table from the configuration file and starts watching the table's paths for changes.

Types

This section is empty.

Jump to